@@ -23,7 +23,7 @@ class FeaturePreprocessorFromTensorflowDataset(tf.keras.layers.Layer, BaseFeatur
         self.feature_preprocessor_list = self.map_preprocessor(self.feature_preprocessor_list)
         self.adapted_preprocessors = dict()
 
-    def adapt(self, dataset):
+    def adapt(self, dataset, *args, **kwargs):
         """Loop through the feature preprocessor list and dapt features with the corresponding preprocessing
         layer. The adapted preprocessing layers can be accessed from the adapted_preprocessors attribute.
 
@@ -38,7 +38,7 @@ class FeaturePreprocessorFromTensorflowDataset(tf.keras.layers.Layer, BaseFeatur
                 cloned_preprocessor = preprocessor if k==0 else preprocessor.from_config(config)
                 feature_ds = extract_feature_column_tensorflow(dataset, feature)
                 # check if layer has adapt method
-                cloned_preprocessor.adapt(feature_ds)
+                cloned_preprocessor.adapt(feature_ds, *args, **kwargs)
                 self.adapted_preprocessors[feature] = cloned_preprocessor
 
     # what if inputs is not of type dict?
@@ -87,7 +87,7 @@ class FeaturePreprocessorFromTensorflowDataset(tf.keras.layers.Layer, BaseFeatur
                 "numerical_features", layers.Normalization(), numeric_features
             ),
             (
-                "categorical_features", layers.IntegerLookup(output_mode="binary"), categoric_features,
+                "categorical_features", layers.IntegerLookup(output_mode="multi_hot"), categoric_features,
             ),
             (
                 "string_categorical_features", StringToIntegerLookup(), string_categoric_features,
@@ -112,7 +112,7 @@ class FeaturePreprocessorFromPandasDataFrame(tf.keras.layers.Layer, BaseFeatureP
         self.feature_preprocessor_list = self.map_preprocessor(feature_preprocessor_list)
         self.adapted_preprocessors = dict()
 
-    def adapt(self, dataset):
+    def adapt(self, dataset, *args, **kwargs):
         """Adapt layers from tf.data.Dataset source type.
 
         Args:
@@ -126,7 +126,7 @@ class FeaturePreprocessorFromPandasDataFrame(tf.keras.layers.Layer, BaseFeatureP
                 cloned_preprocessor = preprocessor if k==0 else preprocessor.from_config(config)
                 feature_ds = extract_feature_column_pandas(dataset, feature)
                 # check if layer has adapt method
-                cloned_preprocessor.adapt(feature_ds)
+                cloned_preprocessor.adapt(feature_ds, *args, **kwargs)
                 self.adapted_preprocessors[feature] = cloned_preprocessor
 
     @tf.function
@@ -147,6 +147,42 @@ class FeaturePreprocessorFromPandasDataFrame(tf.keras.layers.Layer, BaseFeatureP
             ]
         return forward_pass
 
+    @classmethod
+    def from_infered_pipeline(cls, dataset):
+        """Infer preprocessing spec from pd.DataFrame type
+
+        Args:
+            dataset (pd.DataFrame): Training data that contains features and/or target
+
+        Returns:
+            list: steps for preprocessing list
+        """
+        numeric_features = []
+        categoric_features = []
+        string_categoric_features = []
+
+        for feature, _type in dataset.dtypes.items():
+            if str(_type) == 'object':
+                string_categoric_features.append(feature)
+            elif str(_type) in ['int64', 'int32']:
+                categoric_features.append(feature)
+            else:
+                numeric_features.append(feature)
+
+        feature_preprocessor_list = [
+            # FIXME: We will most likely not have all these steps
+            (
+                "numerical_features", layers.Normalization(), numeric_features
+            ),
+            (
+                "categorical_features", layers.IntegerLookup(output_mode="multi_hot"), categoric_features,
+            ),
+            (
+                "string_categorical_features", StringToIntegerLookup(), string_categoric_features,
+            ),
+        ]
+        return feature_preprocessor_list
+
 
 def extract_feature_column_tensorflow(dataset, name):
     """Extract feature from dataset
